TreeTokenizer

Struct TreeTokenizer 

pub struct TreeTokenizer {
    pub universe: Universe,
    pub tree: HashMap<String, Lapper<u32, u32>>,
}
A tokenizer that uses an interval tree to find overlaps

Attributes

  • universe - the universe of regions
  • tree - the interval tree

Methods

  • from - create a new TreeTokenizer from a bed file
  • tokenize_region - tokenize a region into the vocabulary of the tokenizer
  • tokenize_region_set - tokenize a region set into the vocabulary of the tokenizer
  • tokenize_bed_set - tokenize a bed set into the vocabulary of the tokenizer
  • unknown_token - get the unknown token

Fields

universe: Universetree: HashMap<String, Lapper<u32, u32>>

Implementations